==> spip_4.2.9+dfsg.orig.tar.xz: plugins-dist/forum/lang/forum_oc_gsc.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/forum?lang_cible=oc_gsc
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_radio_articles_futurs' => 'aus articles futurs sonque (nada accion sus la basa de dadas).',
	'bouton_radio_articles_tous' => 'aus articles tots shens excepcion',
	'bouton_radio_articles_tous_sauf_forum_desactive' => 'a tots los articles, sauv los qui lo lor forum ei desactivat.',
	'bouton_radio_enregistrement_obligatoire' => 'Registrament obligatòri (los utilizaires que’s deven abonar en dar la lor adreiça e-mail abans de poder mandar contribucions).',
	'bouton_radio_moderation_priori' => 'Moderacion a priòri (las
 contribucions qu’apareishen en public sonque se los administrators
 las an validadas).', # MODIF
	'bouton_radio_modere_abonnement' => 'moderat dab abonament',
	'bouton_radio_modere_posteriori' => 'moderat a posteriòri', # MODIF
	'bouton_radio_modere_priori' => 'moderat a priòri', # MODIF
	'bouton_radio_publication_immediate' => 'Publicar los messatges suu pic
 (las contribucions qu’apareishen tanlèu mandadas, los administrators que las pòden
 suprimir puish).',

	// F
	'form_pet_message_commentaire' => 'Un messatge, ua remarca?',
	'forum' => 'Forum',
	'forum_acces_refuse' => 'Non podetz plus accedir a aqueths forums.',
	'forum_attention_dix_caracteres' => '<b>Atencion!</b> lo vòste messatge que deu tiéner aumensh dètz caractèrs.',
	'forum_attention_trois_caracteres' => '<b>Atencion!</b> lo vòste títol que deu tiéner aumensh de tres caractèrs.',
	'forum_avez_selectionne' => 'Qu’avetz seleccionat:',
	'forum_cliquer_retour' => 'Clicatz <a href=\'@retour_forum@\'>ací</a> tà contunhar.',
	'forum_forum' => 'forum',
	'forum_info_modere' => 'Aqueste forum qu’ei moderat a priòri: la vòsta contribucion que pareisherà sonque après qu’un administrator deu sit l’aja validada.', # MODIF
	'forum_lien_hyper' => '<b>Ligam ipertèxt</b> (opcionau)', # MODIF
	'forum_message_definitif' => 'Messatge definitiu : mandar au sit',
	'forum_message_trop_long' => 'Lo vòste messatge qu’ei tròp long. La longor maximau qu’ei de 20 000 caractèrs.', # MODIF
	'forum_ne_repondez_pas' => 'Non responiatz pas a aqueth e-mail mes peu forum a l’adreiça seguenta: ', # MODIF
	'forum_page_url' => '(se lo vòste messatge e’s refereish a un article publicat peu web, o a ua pagina qui baile mei informacions, que podetz marcar ça devath lo títol de la pagina e la soa adreiça URL.)',
	'forum_poste_par' => 'Messatge poste@parauteur@ qui hè seguida au vòste article.', # MODIF
	'forum_qui_etes_vous' => '<b>Qui ètz?</b> (opcionau)', # MODIF
	'forum_texte' => 'Tèxt deu vòste messatge:', # MODIF
	'forum_titre' => 'Títol:', # MODIF
	'forum_url' => 'URL:', # MODIF
	'forum_valider' => 'Validar aquera causida',
	'forum_voir_avant' => 'Véder lo messatge abans de’u mandar', # MODIF
	'forum_votre_email' => 'La vòsta adreiça e-mail:', # MODIF
	'forum_votre_nom' => 'Lo vòste nom (o pseudonim):', # MODIF
	'forum_vous_enregistrer' => 'Entà participar a
  aqueth forum, en permèras que’vs cau registrar. Mercés
  de marcar ça devath l’identificant personau qui avetz recebut.
 Se n’ètz pas registrat/ada, qu’ei necessari',
	'forum_vous_inscrire' => 'inscrive’vs',

	// I
	'icone_poster_message' => 'Postar un messatge',
	'icone_suivi_forum' => 'Seguit deu forum public: @nb_forums@ contribucion(s)',
	'icone_suivi_forums' => 'Seguir/gerir los forums',
	'icone_supprimer_message' => 'Suprimir aqueth messatge',
	'icone_valider_message' => 'Validar aqueth messatge',
	'info_activer_forum_public' => '<i>Tà activar los forums publics, volhatz causir lo lor mòde de moderacion predefinit:</i>', # MODIF
	'info_appliquer_choix_moderation' => 'Aplicar aquera causida de moderacion:',
	'info_desactiver_forum_public' => 'Desactivar l’utilizacion deus forums publics. Los forums publics que poiràn estar autorizats au cas per cas suus articles; que seràn proïbits sus las rubricas, brèvas, etc.',
	'info_envoi_forum' => 'Mandadís deus forums aus autors deus articles',
	'info_fonctionnement_forum' => 'Foncionament deu forum:',
	'info_gauche_suivi_forum_2' => 'La pagina de <i>seguit deus forums</i> qu’ei un gatge de gestion deu vòste sit (mes n’ei pas un espaci tà discutir o tà redigir). Qu’aficha totas las contribucions deu forum public d’aqueth article e que’vs permet de gerir aqueras contribucions.', # MODIF
	'info_liens_syndiques_3' => 'forums',
	'info_liens_syndiques_4' => 'que son',
	'info_liens_syndiques_5' => 'forum',
	'info_liens_syndiques_6' => 'qu’ei',
	'info_liens_syndiques_7' => 'en espèra de validacion',
	'info_mode_fonctionnement_defaut_forum_public' => 'Mòde de foncionament predefinit deus forums publics',
	'info_option_email' => 'Quan un vesitaire deu sit e manda un messatge nau au forum
 associat a un article, que se’n pòt avisar los autors
 de l’article per e-mail. E desiratz d’utilizar aquera opcion?', # MODIF
	'info_pas_de_forum' => 'Nat forum',
	'item_activer_forum_administrateur' => 'Activar lo forum deus administrators',
	'item_desactiver_forum_administrateur' => 'Desactivar lo forum deus administrators',

	// L
	'lien_reponse_article' => 'Responsa a l’article',
	'lien_reponse_breve_2' => 'Responsa a la brèva',
	'lien_reponse_rubrique' => 'Responsa a la rubrica',
	'lien_reponse_site_reference' => 'Responsa au sit referenciat:', # MODIF

	// O
	'onglet_messages_internes' => 'Messatges intèrnes',
	'onglet_messages_publics' => 'Messatges publics',
	'onglet_messages_vide' => 'Messatges shens tèxt',

	// R
	'repondre_message' => 'Arrespóner a aqueth messatge',

	// T
	'titre_cadre_forum_administrateur' => 'Forum privat deus administrators',
	'titre_cadre_forum_interne' => 'Forum intèrne',
	'titre_forum' => 'Forum',
	'titre_forum_suivi' => 'Seguit deus forums',
	'titre_page_forum_suivi' => 'Seguit deus forums'
);

==> spip_4.2.13+dfsg.orig.tar.xz: plugins-dist/forum/lang/forum_oc_gsc.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/forum?lang_cible=oc_gsc
// ** ne pas modifier le fichier **

return [

	// B
	'bouton_radio_articles_futurs' => 'aus articles futurs sonque (nada accion sus la basa de dadas).',
	'bouton_radio_articles_tous' => 'aus articles tots shens excepcion',
	'bouton_radio_articles_tous_sauf_forum_desactive' => 'a tots los articles, sauv los qui lo lor forum ei desactivat.',
	'bouton_radio_enregistrement_obligatoire' => 'Registrament obligatòri (los utilizaires que’s deven abonar en dar la lor adreiça e-mail abans de poder mandar contribucions).',
	'bouton_radio_moderation_priori' => 'Moderacion a priòri (las
 contribucions qu’apareishen en public sonque se los administrators
 las an validadas).', # MODIF
	'bouton_radio_modere_abonnement' => 'moderat dab abonament',
	'bouton_radio_modere_posteriori' => 'moderat a posteriòri', # MODIF
	'bouton_radio_modere_priori' => 'moderat a priòri', # MODIF
	'bouton_radio_publication_immediate' => 'Publicar los messatges suu pic
 (las contribucions qu’apareishen tanlèu mandadas, los administrators que las pòden
 suprimir puish).',

	// F
	'form_pet_message_commentaire' => 'Un messatge, ua remarca?',
	'forum' => 'Forum',
	'forum_acces_refuse' => 'Non podetz plus accedir a aqueths forums.',
	'forum_attention_dix_caracteres' => '<b>Atencion!</b> lo vòste messatge que deu tiéner aumensh dètz caractèrs.',
	'forum_attention_trois_caracteres' => '<b>Atencion!</b> lo vòste títol que deu tiéner aumensh de tres caractèrs.',
	'forum_avez_selectionne' => 'Qu’avetz seleccionat:',
	'forum_cliquer_retour' => 'Clicatz <a href=\'@retour_forum@\'>ací</a> tà contunhar.',
	'forum_forum' => 'forum',
	'forum_info_modere' => 'Aqueste forum qu’ei moderat a priòri: la vòsta contribucion que pareisherà sonque après qu’un administrator deu sit l’aja validada.', # MODIF
	'forum_lien_hyper' => '<b>Ligam ipertèxt</b> (opcionau)', # MODIF
	'forum_message_definitif' => 'Messatge definitiu : mandar au sit',
	'forum_message_trop_long' => 'Lo vòste messatge qu’ei tròp long. La longor maximau qu’ei de 20 000 caractèrs.', # MODIF
	'forum_ne_repondez_pas' => 'Non responiatz pas a aqueth e-mail mes peu forum a l’adreiça seguenta: ', # MODIF
	'forum_page_url' => '(se lo vòste messatge e’s refereish a un article publicat peu web, o a ua pagina qui baile mei informacions, que podetz marcar ça devath lo títol de la pagina e la soa adreiça URL.)',
	'forum_poste_par' => 'Messatge poste@parauteur@ qui hè seguida au vòste article.', # MODIF
	'forum_qui_etes_vous' => '<b>Qui ètz?</b> (opcionau)', # MODIF
	'forum_texte' => 'Tèxt deu vòste messatge:', # MODIF
	'forum_titre' => 'Títol:', # MODIF
	'forum_url' => 'URL:', # MODIF
	'forum_valider' => 'Validar aquera causida',
	'forum_voir_avant' => 'Véder lo messatge abans de’u mandar', # MODIF
	'forum_votre_email' => 'La vòsta adreiça e-mail:', # MODIF
	'forum_votre_nom' => 'Lo vòste nom (o pseudonim):', # MODIF
	'forum_vous_enregistrer' => 'Entà participar a
  aqueth forum, en permèras que’vs cau registrar. Mercés
  de marcar ça devath l’identificant personau qui avetz recebut.
 Se n’ètz pas registrat/ada, qu’ei necessari',
	'forum_vous_inscrire' => 'inscrive’vs',

	// I
	'icone_poster_message' => 'Postar un messatge',
	'icone_suivi_forum' => 'Seguit deu forum public: @nb_forums@ contribucion(s)',
	'icone_suivi_forums' => 'Seguir/gerir los forums',
	'icone_supprimer_message' => 'Suprimir aqueth messatge',
	'icone_valider_message' => 'Validar aqueth messatge',
	'info_activer_forum_public' => '<i>Tà activar los forums publics, volhatz causir lo lor mòde de moderacion predefinit:</i>', # MODIF
	'info_appliquer_choix_moderation' => 'Aplicar aquera causida de moderacion:',
	'info_desactiver_forum_public' => 'Desactivar l’utilizacion deus forums publics. Los forums publics que poiràn estar autorizats au cas per cas suus articles; que seràn proïbits sus las rubricas, brèvas, etc.',
	'info_envoi_forum' => 'Mandadís deus forums aus autors deus articles',
	'info_fonctionnement_forum' => 'Foncionament deu forum:',
	'info_gauche_suivi_forum_2' => 'La pagina de <i>seguit deus forums</i> qu’ei un gatge de gestion deu vòste sit (mes n’ei pas un espaci tà discutir o tà redigir). Qu’aficha totas las contribucions deu forum public d’aqueth article e que’vs permet de gerir aqueras contribucions.', # MODIF
	'info_liens_syndiques_3' => 'forums',
	'info_liens_syndiques_4' => 'que son',
	'info_liens_syndiques_5' => 'forum',
	'info_liens_syndiques_6' => 'qu’ei',
	'info_liens_syndiques_7' => 'en espèra de validacion',
	'info_mode_fonctionnement_defaut_forum_public' => 'Mòde de foncionament predefinit deus forums publics',
	'info_option_email' => 'Quan un vesitaire deu sit e manda un messatge nau au forum
 associat a un article, que se’n pòt avisar los autors
 de l’article per e-mail. E desiratz d’utilizar aquera opcion?', # MODIF
	'info_pas_de_forum' => 'Nat forum',
	'item_activer_forum_administrateur' => 'Activar lo forum deus administrators',
	'item_desactiver_forum_administrateur' => 'Desactivar lo forum deus administrators',

	// L
	'lien_reponse_article' => 'Responsa a l’article',
	'lien_reponse_breve_2' => 'Responsa a la brèva',
	'lien_reponse_rubrique' => 'Responsa a la rubrica',
	'lien_reponse_site_reference' => 'Responsa au sit referenciat:', # MODIF

	// O
	'onglet_messages_internes' => 'Messatges intèrnes',
	'onglet_messages_publics' => 'Messatges publics',
	'onglet_messages_vide' => 'Messatges shens tèxt',

	// R
	'repondre_message' => 'Arrespóner a aqueth messatge',

	// T
	'titre_cadre_forum_administrateur' => 'Forum privat deus administrators',
	'titre_cadre_forum_interne' => 'Forum intèrne',
	'titre_forum' => 'Forum',
	'titre_forum_suivi' => 'Seguit deus forums',
	'titre_page_forum_suivi' => 'Seguit deus forums',
];
